@@ -1,9 +1,9 @@
 """Representation of ISY Nodes."""
 from asyncio import sleep
+from dataclasses import dataclass
 from xml.dom import minidom
 
 from ..constants import (
-    _LOGGER,
     ATTR_ACTION,
     ATTR_CONTROL,
     ATTR_FLAG,
@@ -22,8 +22,11 @@ from ..constants import (
     FAMILY_ZWAVE,
     INSTEON_RAMP_RATES,
     ISY_VALUE_UNKNOWN,
+    NC_NODE_ENABLED,
     NC_NODE_ERROR,
     NODE_CHANGED_ACTIONS,
+    NODE_IS_CONTROLLER,
+    NODE_IS_ROOT,
     PROP_BATTERY_LEVEL,
     PROP_COMMS_ERROR,
     PROP_RAMP_RATE,
@@ -35,6 +38,7 @@ from ..constants import (
     TAG_ADDRESS,
     TAG_DEVICE_TYPE,
     TAG_ENABLED,
+    TAG_EVENT_INFO,
     TAG_FAMILY,
     TAG_FOLDER,
     TAG_FORMATTED,
@@ -50,6 +54,7 @@ from ..constants import (
 )
 from ..exceptions import XML_ERRORS, XML_PARSE_ERROR, ISYResponseParseError
 from ..helpers import (
+    EventEmitter,
     NodeProperty,
     ZWaveProperties,
     attr_from_element,
@@ -57,6 +62,7 @@ from ..helpers import (
     parse_xml_properties,
     value_from_xml,
 )
+from ..logging import _LOGGER
 from .group import Group
 from .node import Node
 
@@ -106,6 +112,8 @@ class Nodes:
         self.nobjs = []
         self.ntypes = []
 
+        self.status_events = EventEmitter()
+
         if xml is not None:
             self.parse(xml)
             return
@@ -221,7 +229,7 @@ class Nodes:
         node.update_state(
             NodeProperty(PROP_STATUS, value, prec, uom, formatted, address)
         )
-        _LOGGER.debug("ISY Updated Node: " + address)
+        _LOGGER.debug("ISY Updated Node: %s", address)
 
     def control_message_received(self, xmldoc):
         """
@@ -271,7 +279,7 @@ class Nodes:
             node.update_state(
                 NodeProperty(PROP_STATUS, value, prec, uom, formatted, address)
             )
-            _LOGGER.debug("ISY Updated Node: " + address)
+            _LOGGER.debug("ISY Updated Node: %s", address)
         elif cntrl not in EVENT_PROPS_IGNORED:
             node.update_property(node_property)
         node.control_events.notify(node_property)
@@ -282,9 +290,26 @@ class Nodes:
         action = value_from_xml(xmldoc, ATTR_ACTION)
         if not action or action not in NODE_CHANGED_ACTIONS:
             return
+        (event_desc, e_i_keys) = NODE_CHANGED_ACTIONS[action]
         node = value_from_xml(xmldoc, TAG_NODE)
+        detail = {}
+        if e_i_keys and xmldoc.getElementsByTagName(TAG_EVENT_INFO):
+            detail = {key: value_from_xml(xmldoc, key) for key in e_i_keys}
+
         if action == NC_NODE_ERROR:
             _LOGGER.error("ISY Could not communicate with device: %s", node)
+        elif action == NC_NODE_ENABLED and node in self.addresses:
+            node_obj: Node = self.get_by_id(node)
+            # pylint: disable=attribute-defined-outside-init
+            node_obj.enabled = detail[TAG_ENABLED] == XML_TRUE
+
+        self.status_events.notify(event=NodeChangedEvent(node, action, detail))
+        _LOGGER.debug(
+            "ISY received a %s event for node %s %s",
+            event_desc,
+            node,
+            detail if detail else "",
+        )
         # FUTURE: Handle additional node change actions to force updates.
 
     def parse(self, xml):
@@ -295,9 +320,9 @@ class Nodes:
         """
         try:
             xmldoc = minidom.parseString(xml)
-        except XML_ERRORS:
+        except XML_ERRORS as exc:
             _LOGGER.error("%s: Nodes", XML_PARSE_ERROR)
-            raise ISYResponseParseError(XML_PARSE_ERROR)
+            raise ISYResponseParseError(XML_PARSE_ERROR) from exc
 
         # get nodes
         ntypes = [TAG_FOLDER, TAG_NODE, TAG_GROUP]
@@ -316,6 +341,7 @@ class Nodes:
                 family = value_from_xml(feature, TAG_FAMILY)
                 device_type = value_from_xml(feature, TAG_TYPE)
                 node_def_id = attr_from_element(feature, ATTR_NODE_DEF_ID)
+                flag = int(attr_from_element(feature, ATTR_FLAG, 0))
                 enabled = value_from_xml(feature, TAG_ENABLED) == XML_TRUE
 
                 # Assume Insteon, update as confirmed otherwise
@@ -363,18 +389,18 @@ class Nodes:
                             protocol=protocol,
                             family_id=family,
                             state_set=state_set,
+                            flag=flag,
                         ),
                         ntype,
                     )
                 elif ntype == TAG_GROUP and address not in self.addresses:
-                    flag = attr_from_element(feature, ATTR_FLAG)
                     # Ignore groups that contain 0x08 in the flag since
                     # that is a ISY scene that contains every device/
                     # scene so it will contain some scenes we have not
                     # seen yet so they are not defined and it includes
                     # the ISY MAC address in newer versions of
                     # ISY firmwares > 5.0.6+ ..
-                    if int(flag) & 0x08:
+                    if flag & NODE_IS_ROOT:
                         _LOGGER.debug("Skipping root group flag=%s %s", flag, address)
                         continue
                     mems = feature.getElementsByTagName(TAG_LINK)
@@ -383,7 +409,10 @@ class Nodes:
                     # Build list of controllers
                     controllers = []
                     for mem in mems:
-                        if int(attr_from_element(mem, TAG_TYPE, 0)) == 16:
+                        if (
+                            int(attr_from_element(mem, TAG_TYPE, 0))
+                            == NODE_IS_CONTROLLER
+                        ):
                             controllers.append(mem.firstChild.nodeValue)
                     self.insert(
                         address,
@@ -397,6 +426,7 @@ class Nodes:
                             controllers=controllers,
                             family_id=family,
                             pnode=pnode,
+                            flag=flag,
                         ),
                         ntype,
                     )
@@ -631,3 +661,12 @@ class NodeIterator:
     def __len__(self):
         """Return the number of elements."""
         return self._len
+
+
+@dataclass
+class NodeChangedEvent:
+    """Class representation of a node change event."""
+
+    address: str
+    action: str
+    event_info: dict
